==> scala-k8s-objects_sjs1_2.12-0.1.0-sources.jar: io/k8s/api/core/v1/CephFSPersistentVolumeSource.scala <==
package io.k8s.api.core.v1


/** Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling. */
final case class CephFSPersistentVolumeSource(
  monitors : Seq[String],
  path : Option[String] = None,
  readOnly : Option[Boolean] = None,
  secretRef : Option[io.k8s.api.core.v1.SecretReference] = None,
  secretFile : Option[String] = None,
  user : Option[String] = None
) {

  /** Returns a new data with monitors set to new value */
  def withMonitors(value: Seq[String]) : CephFSPersistentVolumeSource = copy(monitors = value)
  /** Appends new values to monitors */
  def addMonitors(newValues: String*) : CephFSPersistentVolumeSource = copy(monitors = monitors ++ newValues)
  /** transforms monitors to result of function */
  def mapMonitors(f: Seq[String] => Seq[String]) : CephFSPersistentVolumeSource = copy(monitors = f(monitors))

  /** Returns a new data with path set to new value */
  def withPath(value: String) : CephFSPersistentVolumeSource = copy(path = Some(value))
  /** if path has a value, transforms to the result of function*/
  def mapPath(f: String => String) : CephFSPersistentVolumeSource = copy(path = path.map(f))

  /** Returns a new data with readOnly set to new value */
  def withReadOnly(value: Boolean) : CephFSPersistentVolumeSource = copy(readOnly = Some(value))
  /** if readOnly has a value, transforms to the result of function*/
  def mapReadOnly(f: Boolean => Boolean) : CephFSPersistentVolumeSource = copy(readOnly = readOnly.map(f))

  /** Returns a new data with secretRef set to new value */
  def withSecretRef(value: io.k8s.api.core.v1.SecretReference) : CephFSPersistentVolumeSource = copy(secretRef = Some(value))
  /** if secretRef has a value, transforms to the result of function*/
  def mapSecretRef(f: io.k8s.api.core.v1.SecretReference => io.k8s.api.core.v1.SecretReference) : CephFSPersistentVolumeSource = copy(secretRef = secretRef.map(f))

  /** Returns a new data with secretFile set to new value */
  def withSecretFile(value: String) : CephFSPersistentVolumeSource = copy(secretFile = Some(value))
  /** if secretFile has a value, transforms to the result of function*/
  def mapSecretFile(f: String => String) : CephFSPersistentVolumeSource = copy(secretFile = secretFile.map(f))

  /** Returns a new data with user set to new value */
  def withUser(value: String) : CephFSPersistentVolumeSource = copy(user = Some(value))
  /** if user has a value, transforms to the result of function*/
  def mapUser(f: String => String) : CephFSPersistentVolumeSource = copy(user = user.map(f))
}

==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/core/v1/CephFSPersistentVolumeSource.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling. */
final case class CephFSPersistentVolumeSource(
  monitors : Seq[String],
  path : Option[String] = None,
  readOnly : Option[Boolean] = None,
  secretRef : Option[io.k8s.api.core.v1.SecretReference] = None,
  secretFile : Option[String] = None,
  user : Option[String] = None
) {

  /** Returns a new data with monitors set to new value */
  def withMonitors(value: Seq[String]) : CephFSPersistentVolumeSource = copy(monitors = value)
  /** Appends new values to monitors */
  def addMonitors(newValues: String*) : CephFSPersistentVolumeSource = copy(monitors = monitors ++ newValues)
  /** transforms monitors to result of function */
  def mapMonitors(f: Seq[String] => Seq[String]) : CephFSPersistentVolumeSource = copy(monitors = f(monitors))

  /** Returns a new data with path set to new value */
  def withPath(value: String) : CephFSPersistentVolumeSource = copy(path = Some(value))
  /** if path has a value, transforms to the result of function*/
  def mapPath(f: String => String) : CephFSPersistentVolumeSource = copy(path = path.map(f))

  /** Returns a new data with readOnly set to new value */
  def withReadOnly(value: Boolean) : CephFSPersistentVolumeSource = copy(readOnly = Some(value))
  /** if readOnly has a value, transforms to the result of function*/
  def mapReadOnly(f: Boolean => Boolean) : CephFSPersistentVolumeSource = copy(readOnly = readOnly.map(f))

  /** Returns a new data with secretRef set to new value */
  def withSecretRef(value: io.k8s.api.core.v1.SecretReference) : CephFSPersistentVolumeSource = copy(secretRef = Some(value))
  /** if secretRef has a value, transforms to the result of function*/
  def mapSecretRef(f: io.k8s.api.core.v1.SecretReference => io.k8s.api.core.v1.SecretReference) : CephFSPersistentVolumeSource = copy(secretRef = secretRef.map(f))

  /** Returns a new data with secretFile set to new value */
  def withSecretFile(value: String) : CephFSPersistentVolumeSource = copy(secretFile = Some(value))
  /** if secretFile has a value, transforms to the result of function*/
  def mapSecretFile(f: String => String) : CephFSPersistentVolumeSource = copy(secretFile = secretFile.map(f))

  /** Returns a new data with user set to new value */
  def withUser(value: String) : CephFSPersistentVolumeSource = copy(user = Some(value))
  /** if user has a value, transforms to the result of function*/
  def mapUser(f: String => String) : CephFSPersistentVolumeSource = copy(user = user.map(f))
}

object CephFSPersistentVolumeSource {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.CephFSPersistentVolumeSource, T] = new Encoder[io.k8s.api.core.v1.CephFSPersistentVolumeSource, T] {
        def apply(o: io.k8s.api.core.v1.CephFSPersistentVolumeSource) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("monitors", o.monitors)
            .write("path", o.path)
            .write("readOnly", o.readOnly)
            .write("secretRef", o.secretRef)
            .write("secretFile", o.secretFile)
            .write("user", o.user)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, CephFSPersistentVolumeSource] = new Decoder[T, CephFSPersistentVolumeSource] {
      def apply(t: T): Either[String, CephFSPersistentVolumeSource] = for {
          obj <- ObjectReader(t)
          monitors <- obj.read[Seq[String]]("monitors")
          path <- obj.readOpt[String]("path")
          readOnly <- obj.readOpt[Boolean]("readOnly")
          secretRef <- obj.readOpt[io.k8s.api.core.v1.SecretReference]("secretRef")
          secretFile <- obj.readOpt[String]("secretFile")
          user <- obj.readOpt[String]("user")
      } yield CephFSPersistentVolumeSource (
          monitors = monitors,
          path = path,
          readOnly = readOnly,
          secretRef = secretRef,
          secretFile = secretFile,
          user = user
        )
    }
}
